import arrayFrom from 'core-js/fn/array/from'
import objectAssign from 'core-js/fn/object/assign'
import format from 'string-template'
import extend from 'lodash/extend'
import { createClient } from 'contentful'

Array.from = arrayFrom
Object.assign = objectAssign

let data
let client
let settings
const locale = navigator.languages ? navigator.languages[0] : (navigator.language || navigator.userLanguage)

const localeWithoutSuffix = locale => locale.split('-')[0]

const getEntries = (contentTypeId) => client.getEntries({
  locale: localeWithoutSuffix(locale),
  content_type: contentTypeId
})

const getFieldsWithIncludes = (contentTypeId) => new Promise((resolve, reject) => {
  getEntries(contentTypeId)
  .then(({includes, items}) => {
    const includesFields = includes.Entry.map(({fields}) => fields)
    data = Object.assign(...includesFields)
  })
  .then(() => {
    resolve(data)
  })
})

const getFields = (contentTypeId) => new Promise((resolve, reject) => {
  getEntries(contentTypeId).then(({items}) => items.forEach(({fields}) => {
    data = fields
  })).then(() => {
    resolve(data)
  })
})

const VueContentful = {
  install (Vue, options) {
    settings = extend({
      space_id: null,
      access_token: null,
      content_type_id: null
    }, options)

    Vue.prototype.$t = null

    client = createClient({
      space: settings.space_id,
      accessToken: settings.access_token
    })

    Vue.prototype.$getLangFields = contentTypeId => getFields(contentTypeId)
    Vue.prototype.$trans = (data, ...args) => format(data, ...args)
    Vue.prototype.$transChoice = (str, i, sep = ',') => str.split(sep)[i]
  },
  init (Vue) {
    return new Promise((resolve, reject) => {
      getFieldsWithIncludes(settings.content_type_id).then(() => {
        Vue.prototype.$t = data
        resolve(data)
      })
    })
  }
}

export default VueContentful
